@@ -63,10 +63,6 @@ class FabricationElement(object):
         self.egress_frame_distance = egress_frame_distance
         self.attrs = attrs or {}
 
-        # Not included in data functions since this value is only valid during
-        # fabrication run.
-        self.cycle_time_future = None  # type: FutureResult
-
     def __repr__(self):
         return "FabricationElement({}, {}, {}, {}. {})".format(
             self.location,
@@ -89,7 +85,7 @@ class FabricationElement(object):
         }
 
     @data.setter
-    def data(self, data):
+    def data(self, data):  # type: (dict) -> None
         self.location = data["location"]
         self.id_ = data["id_"]
         self.radius = data["radius"]
@@ -97,7 +93,7 @@ class FabricationElement(object):
         self.egress_frame_distance = data["egress_frame_distance"]
         self.attrs = data["attrs"]
 
-    def transform(self, transformation):
+    def transform(self, transformation):  # type: (cg.Transformation) -> None
         """Get a transformed copy of :class:`FabricationElement`.
 
         Parameters
@@ -132,7 +128,7 @@ class FabricationElement(object):
         :class:`compas.geometry.Frame`
         """
         vector = self.get_normal() * self.height
-        T = cg.Translation(vector)
+        T = cg.Translation.from_vector(vector)
 
         return self.location.transformed(T)
 
@@ -144,7 +140,7 @@ class FabricationElement(object):
         :class:`compas.geometry.Frame`
         """
         vector = self.get_normal() * self.egress_frame_distance
-        T = cg.Translation(vector)
+        T = cg.Translation.from_vector(vector)
 
         return self.get_top_frame().transformed(T)
 
@@ -404,21 +400,26 @@ class PlaceElement(FabricationElement):
         self.placed = placed
         self.time_placed = time_placed
 
+        # Not included in data setter and getter since these values are run specific
+        self.skip = False
+        self.cycle_time_future = None  # type: FutureResult
+
     @property
     def data(self):
         """:obj:`dict` : The data dictionary that represents the :class:`PlaceElement`."""  # noqa: E501
         data = super(PlaceElement, self).data
 
         data["compression_ratio"] = self.compression_ratio
-        data["cycle_time"] = self.cycle_time
-        data["placed"] = self.placed
-        data["time_placed"] = self.time_placed
 
         data["travel_trajectories"] = self.travel_trajectories
         data["return_travel_trajectories"] = self.return_travel_trajectories
         data["place_trajectories"] = self.place_trajectories
         data["return_place_trajectories"] = self.return_place_trajectories
 
+        data["cycle_time"] = self.cycle_time
+        data["placed"] = self.placed
+        data["time_placed"] = self.time_placed
+
         return data
 
     @data.setter
@@ -428,15 +429,16 @@ class PlaceElement(FabricationElement):
         super(PlaceElement, self.__class__).data.fset(self, data)
 
         self.compression_ratio = data.get("compression_ratio")
-        self.cycle_time = data.get("cycle_time")
-        self.placed = data.get("placed")
-        self.time_placed = data.get("time_placed")
 
         self.travel_trajectories = data.get("travel_trajectories")
         self.return_travel_trajectories = data.get("return_travel_trajectories")
         self.place_trajectories = data.get("place_trajectories")
         self.return_place_trajectories = data.get("return_place_trajectories")
 
+        self.cycle_time = data.get("cycle_time")
+        self.placed = data.get("placed")
+        self.time_placed = data.get("time_placed")
+
     # Derived frames
     ################
 
@@ -459,7 +461,7 @@ class PlaceElement(FabricationElement):
         :class:`compas.geometry.Frame`
         """
         vector = self.get_normal() * self.get_compressed_height()
-        T = cg.Translation(vector)
+        T = cg.Translation.from_vector(vector)
 
         return self.location.transformed(T)
 
